"""
Generated class for Ingredient. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Ratio import *
from fhirmodels.R5.RatioRange import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Manufacturer(FhirBaseModel):
    """The organization(s) that manufacture this ingredient. Can be used to indicate:         1) Organizations we are aware of that manufacture this ingredient         2) Specific Manufacturer(s) currently being used         3) Set of organisations allowed to manufacture this ingredient for this product         Users must be clear on the application of context relevant to their use case.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str role: allowed | possible | actual
    :param Reference manufacturer: An organization that manufactures this ingredient
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "manufacturer": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        role: "str" = None,
        manufacturer: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.role = role
        self.manufacturer = manufacturer

    @classmethod
    def from_dict(cls, data: dict) -> "Ingredient":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Ingredient":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ReferenceStrength(FhirBaseModel):
    """Strength expressed in terms of a reference substance. For when the ingredient strength is additionally expressed as equivalent to the strength of some other closely related substance (e.g. salt vs. base). Reference strength represents the strength (quantitative composition) of the active moiety of the active substance. There are situations when the active substance and active moiety are different, therefore both a strength and a reference strength are needed.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference substance: Relevant reference substance
    :param Ratio strengthRatio: Strength expressed in terms of a reference substance
    :param RatioRange strengthRatioRange: Strength expressed in terms of a reference substance
    :param Quantity strengthQuantity: Strength expressed in terms of a reference substance
    :param str measurementPoint: When strength is measured at a particular point or distance
    :param CodeableConcept country: Where the strength range applies
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "substance": {"class_name": "CodeableReference", "is_contained": False},
        "strengthRatio": {"class_name": "Ratio", "is_contained": False},
        "strengthRatioRange": {"class_name": "RatioRange", "is_contained": False},
        "strengthQuantity": {"class_name": "Quantity", "is_contained": False},
        "country": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        substance: "CodeableReference" = None,
        strengthRatio: "Ratio" = None,
        strengthRatioRange: "RatioRange" = None,
        strengthQuantity: "Quantity" = None,
        measurementPoint: "str" = None,
        country: list["CodeableConcept"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.substance = substance
        self.strengthRatio = strengthRatio
        self.strengthRatioRange = strengthRatioRange
        self.strengthQuantity = strengthQuantity
        self.measurementPoint = measurementPoint
        self.country = country or []

    @classmethod
    def from_dict(cls, data: dict) -> "Ingredient":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Ingredient":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Strength(FhirBaseModel):
    """The quantity of substance in the unit of presentation, or in the volume (or mass) of the single pharmaceutical product or manufactured item. The allowed repetitions do not represent different strengths, but are different representations - mathematically equivalent - of a single strength.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Ratio presentationRatio: The quantity of substance in the unit of presentation
    :param RatioRange presentationRatioRange: The quantity of substance in the unit of presentation
    :param CodeableConcept presentationCodeableConcept: The quantity of substance in the unit of presentation
    :param Quantity presentationQuantity: The quantity of substance in the unit of presentation
    :param str textPresentation: Text of either the whole presentation strength or a part of it (rest being in Strength.presentation as a ratio)
    :param Ratio concentrationRatio: The strength per unitary volume (or mass)
    :param RatioRange concentrationRatioRange: The strength per unitary volume (or mass)
    :param CodeableConcept concentrationCodeableConcept: The strength per unitary volume (or mass)
    :param Quantity concentrationQuantity: The strength per unitary volume (or mass)
    :param str textConcentration: Text of either the whole concentration strength or a part of it (rest being in Strength.concentration as a ratio)
    :param CodeableConcept basis: A code that indicates if the strength is, for example, based on the ingredient substance as stated or on the substance base (when the ingredient is a salt)
    :param str measurementPoint: When strength is measured at a particular point or distance
    :param CodeableConcept country: Where the strength range applies
    :param ReferenceStrength referenceStrength: Strength expressed in terms of a reference substance
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "presentationRatio": {"class_name": "Ratio", "is_contained": False},
        "presentationRatioRange": {"class_name": "RatioRange", "is_contained": False},
        "presentationCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "presentationQuantity": {"class_name": "Quantity", "is_contained": False},
        "concentrationRatio": {"class_name": "Ratio", "is_contained": False},
        "concentrationRatioRange": {"class_name": "RatioRange", "is_contained": False},
        "concentrationCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "concentrationQuantity": {"class_name": "Quantity", "is_contained": False},
        "basis": {"class_name": "CodeableConcept", "is_contained": False},
        "country": {"class_name": "CodeableConcept", "is_contained": False},
        "referenceStrength": {"class_name": "ReferenceStrength", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        presentationRatio: "Ratio" = None,
        presentationRatioRange: "RatioRange" = None,
        presentationCodeableConcept: "CodeableConcept" = None,
        presentationQuantity: "Quantity" = None,
        textPresentation: "str" = None,
        concentrationRatio: "Ratio" = None,
        concentrationRatioRange: "RatioRange" = None,
        concentrationCodeableConcept: "CodeableConcept" = None,
        concentrationQuantity: "Quantity" = None,
        textConcentration: "str" = None,
        basis: "CodeableConcept" = None,
        measurementPoint: "str" = None,
        country: list["CodeableConcept"] = None,
        referenceStrength: list["ReferenceStrength"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.presentationRatio = presentationRatio
        self.presentationRatioRange = presentationRatioRange
        self.presentationCodeableConcept = presentationCodeableConcept
        self.presentationQuantity = presentationQuantity
        self.textPresentation = textPresentation
        self.concentrationRatio = concentrationRatio
        self.concentrationRatioRange = concentrationRatioRange
        self.concentrationCodeableConcept = concentrationCodeableConcept
        self.concentrationQuantity = concentrationQuantity
        self.textConcentration = textConcentration
        self.basis = basis
        self.measurementPoint = measurementPoint
        self.country = country or []
        self.referenceStrength = referenceStrength or []

    @classmethod
    def from_dict(cls, data: dict) -> "Ingredient":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Ingredient":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Substance(FhirBaseModel):
    """The substance that comprises this ingredient.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference code: A code or full resource that represents the ingredient substance
    :param Strength strength: The quantity of substance, per presentation, or per volume or mass, and type of quantity
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableReference", "is_contained": False},
        "strength": {"class_name": "Strength", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableReference" = None,
        strength: list["Strength"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.strength = strength or []

    @classmethod
    def from_dict(cls, data: dict) -> "Ingredient":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Ingredient":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Ingredient(DomainResource):
    """An ingredient of a manufactured item or pharmaceutical product.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: An identifier or code by which the ingredient can be referenced
    :param str status: draft | active | retired | unknown
    :param Reference _for: The product which this ingredient is a constituent part of
    :param CodeableConcept role: Purpose of the ingredient within the product, e.g. active, inactive
    :param CodeableConcept function: Precise action within the drug product, e.g. antioxidant, alkalizing agent
    :param CodeableConcept group: A classification of the ingredient according to where in the physical item it tends to be used, such the outer shell of a tablet, inner body or ink
    :param bool allergenicIndicator: If the ingredient is a known or suspected allergen
    :param str comment: A place for providing any notes that are relevant to the component, e.g. removed during process, adjusted for loss on drying
    :param Manufacturer manufacturer: An organization that manufactures this ingredient
    :param Substance substance: The substance that comprises this ingredient
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "_for": {"class_name": "Reference", "is_contained": False},
        "role": {"class_name": "CodeableConcept", "is_contained": False},
        "function": {"class_name": "CodeableConcept", "is_contained": False},
        "group": {"class_name": "CodeableConcept", "is_contained": False},
        "manufacturer": {"class_name": "Manufacturer", "is_contained": True},
        "substance": {"class_name": "Substance", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: "Identifier" = None,
        status: "str" = None,
        _for: list["Reference"] = None,
        role: "CodeableConcept" = None,
        function: list["CodeableConcept"] = None,
        group: "CodeableConcept" = None,
        allergenicIndicator: "bool" = None,
        comment: "str" = None,
        manufacturer: list["Manufacturer"] = None,
        substance: "Substance" = None,
    ):

        self.resourceType = "Ingredient"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier
        self.status = status
        self._for = _for or []
        self.role = role
        self.function = function or []
        self.group = group
        self.allergenicIndicator = allergenicIndicator
        self.comment = comment
        self.manufacturer = manufacturer or []
        self.substance = substance

    @classmethod
    def from_dict(cls, data: dict) -> "Ingredient":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Ingredient":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MedicinalProductPackaged. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.MarketingStatus import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.ProdCharacteristic import *
from fhirmodels.R4.ProductShelfLife import *
from fhirmodels.R4.Quantity import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class BatchIdentifier(FhirBaseModel):
    """Batch numbering.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier outerPackaging: A number appearing on the outer packaging of a specific batch
    :param Identifier immediatePackaging: A number appearing on the immediate packaging (and not the outer packaging)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "outerPackaging": {"class_name": "Identifier", "is_contained": False},
        "immediatePackaging": {"class_name": "Identifier", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        outerPackaging: "Identifier" = None,
        immediatePackaging: "Identifier" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.outerPackaging = outerPackaging
        self.immediatePackaging = immediatePackaging

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductPackaged":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductPackaged":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class PackageItem(FhirBaseModel):
    """A packaging item, as a contained for medicine, possibly with other packaging items within.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier identifier: Including possibly Data Carrier Identifier
    :param CodeableConcept type: The physical type of the container of the medicine
    :param Quantity quantity: The quantity of this package in the medicinal product, at the current level of packaging. The outermost is always 1
    :param CodeableConcept material: Material type of the package item
    :param CodeableConcept alternateMaterial: A possible alternate material for the packaging
    :param Reference device: A device accompanying a medicinal product
    :param Reference manufacturedItem: The manufactured item as contained in the packaged medicinal product
    :param PackageItem packageItem: Allows containers within containers
    :param ProdCharacteristic physicalCharacteristics: Dimensions, color etc.
    :param CodeableConcept otherCharacteristics: Other codeable characteristics
    :param ProductShelfLife shelfLifeStorage: Shelf Life and storage information
    :param Reference manufacturer: Manufacturer of this Package Item
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "material": {"class_name": "CodeableConcept", "is_contained": False},
        "alternateMaterial": {"class_name": "CodeableConcept", "is_contained": False},
        "device": {"class_name": "Reference", "is_contained": False},
        "manufacturedItem": {"class_name": "Reference", "is_contained": False},
        "packageItem": {"class_name": "PackageItem", "is_contained": True},
        "physicalCharacteristics": {
            "class_name": "ProdCharacteristic",
            "is_contained": False,
        },
        "otherCharacteristics": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "shelfLifeStorage": {"class_name": "ProductShelfLife", "is_contained": False},
        "manufacturer": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        type: "CodeableConcept" = None,
        quantity: "Quantity" = None,
        material: list["CodeableConcept"] = None,
        alternateMaterial: list["CodeableConcept"] = None,
        device: list["Reference"] = None,
        manufacturedItem: list["Reference"] = None,
        packageItem: list["PackageItem"] = None,
        physicalCharacteristics: "ProdCharacteristic" = None,
        otherCharacteristics: list["CodeableConcept"] = None,
        shelfLifeStorage: list["ProductShelfLife"] = None,
        manufacturer: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.type = type
        self.quantity = quantity
        self.material = material or []
        self.alternateMaterial = alternateMaterial or []
        self.device = device or []
        self.manufacturedItem = manufacturedItem or []
        self.packageItem = packageItem or []
        self.physicalCharacteristics = physicalCharacteristics
        self.otherCharacteristics = otherCharacteristics or []
        self.shelfLifeStorage = shelfLifeStorage or []
        self.manufacturer = manufacturer or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductPackaged":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductPackaged":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MedicinalProductPackaged(DomainResource):
    """A medicinal product in a container or package.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Unique identifier
    :param Reference subject: The product with this is a pack for
    :param str description: Textual description
    :param CodeableConcept legalStatusOfSupply: The legal status of supply of the medicinal product as classified by the regulator
    :param MarketingStatus marketingStatus: Marketing information
    :param Reference marketingAuthorization: Manufacturer of this Package Item
    :param Reference manufacturer: Manufacturer of this Package Item
    :param BatchIdentifier batchIdentifier: Batch numbering
    :param PackageItem packageItem: A packaging item, as a contained for medicine, possibly with other packaging items within
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "legalStatusOfSupply": {"class_name": "CodeableConcept", "is_contained": False},
        "marketingStatus": {"class_name": "MarketingStatus", "is_contained": False},
        "marketingAuthorization": {"class_name": "Reference", "is_contained": False},
        "manufacturer": {"class_name": "Reference", "is_contained": False},
        "batchIdentifier": {"class_name": "BatchIdentifier", "is_contained": True},
        "packageItem": {"class_name": "PackageItem", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        subject: list["Reference"] = None,
        description: "str" = None,
        legalStatusOfSupply: "CodeableConcept" = None,
        marketingStatus: list["MarketingStatus"] = None,
        marketingAuthorization: "Reference" = None,
        manufacturer: list["Reference"] = None,
        batchIdentifier: list["BatchIdentifier"] = None,
        packageItem: list["PackageItem"] = None,
    ):

        self.resourceType = "MedicinalProductPackaged"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.subject = subject or []
        self.description = description
        self.legalStatusOfSupply = legalStatusOfSupply
        self.marketingStatus = marketingStatus or []
        self.marketingAuthorization = marketingAuthorization
        self.manufacturer = manufacturer or []
        self.batchIdentifier = batchIdentifier or []
        self.packageItem = packageItem or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductPackaged":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductPackaged":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for CarePlan. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.Annotation import *
from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Quantity import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *
from fhirmodels.R4.Timing import *


class Detail(FhirBaseModel):
    """A simple summary of a planned activity suitable for a general care plan system (e.g. form driven) that doesn't know about specific resources such as procedure etc.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str kind: Appointment | CommunicationRequest | DeviceRequest | MedicationRequest | NutritionOrder | Task | ServiceRequest | VisionPrescription
    :param str instantiatesCanonical: Instantiates FHIR protocol or definition
    :param str instantiatesUri: Instantiates external protocol or definition
    :param CodeableConcept code: Detail type of activity
    :param CodeableConcept reasonCode: Why activity should be done or why activity was prohibited
    :param Reference reasonReference: Why activity is needed
    :param Reference goal: Goals this activity relates to
    :param str status: not-started | scheduled | in-progress | on-hold | completed | cancelled | stopped | unknown | entered-in-error
    :param CodeableConcept statusReason: Reason for current status
    :param bool doNotPerform: If true, activity is prohibiting action
    :param Timing scheduledTiming: When activity is to occur
    :param Period scheduledPeriod: When activity is to occur
    :param str scheduledString: When activity is to occur
    :param Reference location: Where it should happen
    :param Reference performer: Who will be responsible?
    :param CodeableConcept productCodeableConcept: What is to be administered/supplied
    :param Reference productReference: What is to be administered/supplied
    :param Quantity dailyAmount: How to consume/day?
    :param Quantity quantity: How much to administer/supply/consume
    :param str description: Extra info describing activity to perform
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "reasonCode": {"class_name": "CodeableConcept", "is_contained": False},
        "reasonReference": {"class_name": "Reference", "is_contained": False},
        "goal": {"class_name": "Reference", "is_contained": False},
        "statusReason": {"class_name": "CodeableConcept", "is_contained": False},
        "scheduledTiming": {"class_name": "Timing", "is_contained": False},
        "scheduledPeriod": {"class_name": "Period", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
        "performer": {"class_name": "Reference", "is_contained": False},
        "productCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "productReference": {"class_name": "Reference", "is_contained": False},
        "dailyAmount": {"class_name": "Quantity", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        kind: "str" = None,
        instantiatesCanonical: list["str"] = None,
        instantiatesUri: list["str"] = None,
        code: "CodeableConcept" = None,
        reasonCode: list["CodeableConcept"] = None,
        reasonReference: list["Reference"] = None,
        goal: list["Reference"] = None,
        status: "str" = None,
        statusReason: "CodeableConcept" = None,
        doNotPerform: "bool" = None,
        scheduledTiming: "Timing" = None,
        scheduledPeriod: "Period" = None,
        scheduledString: "str" = None,
        location: "Reference" = None,
        performer: list["Reference"] = None,
        productCodeableConcept: "CodeableConcept" = None,
        productReference: "Reference" = None,
        dailyAmount: "Quantity" = None,
        quantity: "Quantity" = None,
        description: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.kind = kind
        self.instantiatesCanonical = instantiatesCanonical or []
        self.instantiatesUri = instantiatesUri or []
        self.code = code
        self.reasonCode = reasonCode or []
        self.reasonReference = reasonReference or []
        self.goal = goal or []
        self.status = status
        self.statusReason = statusReason
        self.doNotPerform = doNotPerform
        self.scheduledTiming = scheduledTiming
        self.scheduledPeriod = scheduledPeriod
        self.scheduledString = scheduledString
        self.location = location
        self.performer = performer or []
        self.productCodeableConcept = productCodeableConcept
        self.productReference = productReference
        self.dailyAmount = dailyAmount
        self.quantity = quantity
        self.description = description

    @classmethod
    def from_dict(cls, data: dict) -> "CarePlan":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CarePlan":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Activity(FhirBaseModel):
    """Identifies a planned action to occur as part of the plan.  For example, a medication to be used, lab tests to perform, self-monitoring, education, etc.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept outcomeCodeableConcept: Results of the activity
    :param Reference outcomeReference: Appointment, Encounter, Procedure, etc.
    :param Annotation progress: Comments about the activity status/progress
    :param Reference reference: Activity details defined in specific resource
    :param Detail detail: In-line definition of activity
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "outcomeCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "outcomeReference": {"class_name": "Reference", "is_contained": False},
        "progress": {"class_name": "Annotation", "is_contained": False},
        "reference": {"class_name": "Reference", "is_contained": False},
        "detail": {"class_name": "Detail", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        outcomeCodeableConcept: list["CodeableConcept"] = None,
        outcomeReference: list["Reference"] = None,
        progress: list["Annotation"] = None,
        reference: "Reference" = None,
        detail: "Detail" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.outcomeCodeableConcept = outcomeCodeableConcept or []
        self.outcomeReference = outcomeReference or []
        self.progress = progress or []
        self.reference = reference
        self.detail = detail

    @classmethod
    def from_dict(cls, data: dict) -> "CarePlan":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CarePlan":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class CarePlan(DomainResource):
    """Describes the intention of how one or more practitioners intend to deliver care for a particular patient, group or community for a period of time, possibly limited to care for a specific condition or set of conditions.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External Ids for this plan
    :param str instantiatesCanonical: Instantiates FHIR protocol or definition
    :param str instantiatesUri: Instantiates external protocol or definition
    :param Reference basedOn: Fulfills CarePlan
    :param Reference replaces: CarePlan replaced by this CarePlan
    :param Reference partOf: Part of referenced CarePlan
    :param str status: draft | active | on-hold | revoked | completed | entered-in-error | unknown
    :param str intent: proposal | plan | order | option
    :param CodeableConcept category: Type of plan
    :param str title: Human-friendly name for the care plan
    :param str description: Summary of nature of plan
    :param Reference subject: Who the care plan is for
    :param Reference encounter: Encounter created as part of
    :param Period period: Time period plan covers
    :param str created: Date record was first recorded
    :param Reference author: Who is the designated responsible party
    :param Reference contributor: Who provided the content of the care plan
    :param Reference careTeam: Who's involved in plan?
    :param Reference addresses: Health issues this plan addresses
    :param Reference supportingInfo: Information considered as part of plan
    :param Reference goal: Desired outcome of plan
    :param Activity activity: Action to occur as part of plan
    :param Annotation note: Comments about the plan
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "replaces": {"class_name": "Reference", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "author": {"class_name": "Reference", "is_contained": False},
        "contributor": {"class_name": "Reference", "is_contained": False},
        "careTeam": {"class_name": "Reference", "is_contained": False},
        "addresses": {"class_name": "Reference", "is_contained": False},
        "supportingInfo": {"class_name": "Reference", "is_contained": False},
        "goal": {"class_name": "Reference", "is_contained": False},
        "activity": {"class_name": "Activity", "is_contained": True},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        instantiatesCanonical: list["str"] = None,
        instantiatesUri: list["str"] = None,
        basedOn: list["Reference"] = None,
        replaces: list["Reference"] = None,
        partOf: list["Reference"] = None,
        status: "str" = None,
        intent: "str" = None,
        category: list["CodeableConcept"] = None,
        title: "str" = None,
        description: "str" = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        period: "Period" = None,
        created: "str" = None,
        author: "Reference" = None,
        contributor: list["Reference"] = None,
        careTeam: list["Reference"] = None,
        addresses: list["Reference"] = None,
        supportingInfo: list["Reference"] = None,
        goal: list["Reference"] = None,
        activity: list["Activity"] = None,
        note: list["Annotation"] = None,
    ):

        self.resourceType = "CarePlan"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.instantiatesCanonical = instantiatesCanonical or []
        self.instantiatesUri = instantiatesUri or []
        self.basedOn = basedOn or []
        self.replaces = replaces or []
        self.partOf = partOf or []
        self.status = status
        self.intent = intent
        self.category = category or []
        self.title = title
        self.description = description
        self.subject = subject
        self.encounter = encounter
        self.period = period
        self.created = created
        self.author = author
        self.contributor = contributor or []
        self.careTeam = careTeam or []
        self.addresses = addresses or []
        self.supportingInfo = supportingInfo or []
        self.goal = goal or []
        self.activity = activity or []
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "CarePlan":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CarePlan":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ResearchSubject. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Progress(FhirBaseModel):
    """The current state (status) of the subject and resons for status change where appropriate.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: state | milestone
    :param CodeableConcept subjectState: candidate | eligible | follow-up | ineligible | not-registered | off-study | on-study | on-study-intervention | on-study-observation | pending-on-study | potential-candidate | screening | withdrawn
    :param CodeableConcept milestone: SignedUp | Screened | Randomized
    :param CodeableConcept reason: State change reason
    :param str startDate: State change date
    :param str endDate: State change date
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "subjectState": {"class_name": "CodeableConcept", "is_contained": False},
        "milestone": {"class_name": "CodeableConcept", "is_contained": False},
        "reason": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        subjectState: "CodeableConcept" = None,
        milestone: "CodeableConcept" = None,
        reason: "CodeableConcept" = None,
        startDate: "str" = None,
        endDate: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.subjectState = subjectState
        self.milestone = milestone
        self.reason = reason
        self.startDate = startDate
        self.endDate = endDate

    @classmethod
    def from_dict(cls, data: dict) -> "ResearchSubject":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ResearchSubject":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ResearchSubject(DomainResource):
    """A ResearchSubject is a participant or object which is the recipient of investigative activities in a research study.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business Identifier for research subject in a study
    :param str status: draft | active | retired | unknown
    :param Progress progress: Subject status
    :param Period period: Start and end of participation
    :param Reference study: Study subject is part of
    :param Reference subject: Who or what is part of study
    :param str assignedComparisonGroup: What path should be followed
    :param str actualComparisonGroup: What path was followed
    :param Reference consent: Agreement to participate in study
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "progress": {"class_name": "Progress", "is_contained": True},
        "period": {"class_name": "Period", "is_contained": False},
        "study": {"class_name": "Reference", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "consent": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        progress: list["Progress"] = None,
        period: "Period" = None,
        study: "Reference" = None,
        subject: "Reference" = None,
        assignedComparisonGroup: "str" = None,
        actualComparisonGroup: "str" = None,
        consent: list["Reference"] = None,
    ):

        self.resourceType = "ResearchSubject"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.progress = progress or []
        self.period = period
        self.study = study
        self.subject = subject
        self.assignedComparisonGroup = assignedComparisonGroup
        self.actualComparisonGroup = actualComparisonGroup
        self.consent = consent or []

    @classmethod
    def from_dict(cls, data: dict) -> "ResearchSubject":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ResearchSubject":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for AdverseEvent. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class Causality(FhirBaseModel):
    """Information on the possible cause of the event.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept assessment: Assessment of if the entity caused the event
    :param str productRelatedness: AdverseEvent.suspectEntity.causalityProductRelatedness
    :param Reference author: AdverseEvent.suspectEntity.causalityAuthor
    :param CodeableConcept method: ProbabilityScale | Bayesian | Checklist
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "assessment": {"class_name": "CodeableConcept", "is_contained": False},
        "author": {"class_name": "Reference", "is_contained": False},
        "method": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        assessment: "CodeableConcept" = None,
        productRelatedness: "str" = None,
        author: "Reference" = None,
        method: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.assessment = assessment
        self.productRelatedness = productRelatedness
        self.author = author
        self.method = method

    @classmethod
    def from_dict(cls, data: dict) -> "AdverseEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AdverseEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SuspectEntity(FhirBaseModel):
    """Describes the entity that is suspected to have caused the adverse event.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference instance: Refers to the specific entity that caused the adverse event
    :param Causality causality: Information on the possible cause of the event
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "instance": {"class_name": "Reference", "is_contained": False},
        "causality": {"class_name": "Causality", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        instance: "Reference" = None,
        causality: list["Causality"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.instance = instance
        self.causality = causality or []

    @classmethod
    def from_dict(cls, data: dict) -> "AdverseEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AdverseEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class AdverseEvent(DomainResource):
    """Actual or  potential/avoided event causing unintended physical injury resulting from or contributed to by medical care, a research study or other healthcare setting factors that requires additional monitoring, treatment, or hospitalization, or that results in death.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier for the event
    :param str actuality: actual | potential
    :param CodeableConcept category: product-problem | product-quality | product-use-error | wrong-dose | incorrect-prescribing-information | wrong-technique | wrong-route-of-administration | wrong-rate | wrong-duration | wrong-time | expired-drug | medical-device-use-error | problem-different-manufacturer | unsafe-physical-environment
    :param CodeableConcept event: Type of the event itself in relation to the subject
    :param Reference subject: Subject impacted by event
    :param Reference encounter: Encounter created as part of
    :param str date: When the event occurred
    :param str detected: When the event was detected
    :param str recordedDate: When the event was recorded
    :param Reference resultingCondition: Effect on the subject due to this event
    :param Reference location: Location where adverse event occurred
    :param CodeableConcept seriousness: Seriousness of the event
    :param CodeableConcept severity: mild | moderate | severe
    :param CodeableConcept outcome: resolved | recovering | ongoing | resolvedWithSequelae | fatal | unknown
    :param Reference recorder: Who recorded the adverse event
    :param Reference contributor: Who  was involved in the adverse event or the potential adverse event
    :param SuspectEntity suspectEntity: The suspected agent causing the adverse event
    :param Reference subjectMedicalHistory: AdverseEvent.subjectMedicalHistory
    :param Reference referenceDocument: AdverseEvent.referenceDocument
    :param Reference study: AdverseEvent.study
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "event": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "resultingCondition": {"class_name": "Reference", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
        "seriousness": {"class_name": "CodeableConcept", "is_contained": False},
        "severity": {"class_name": "CodeableConcept", "is_contained": False},
        "outcome": {"class_name": "CodeableConcept", "is_contained": False},
        "recorder": {"class_name": "Reference", "is_contained": False},
        "contributor": {"class_name": "Reference", "is_contained": False},
        "suspectEntity": {"class_name": "SuspectEntity", "is_contained": True},
        "subjectMedicalHistory": {"class_name": "Reference", "is_contained": False},
        "referenceDocument": {"class_name": "Reference", "is_contained": False},
        "study": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: "Identifier" = None,
        actuality: "str" = None,
        category: list["CodeableConcept"] = None,
        event: "CodeableConcept" = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        date: "str" = None,
        detected: "str" = None,
        recordedDate: "str" = None,
        resultingCondition: list["Reference"] = None,
        location: "Reference" = None,
        seriousness: "CodeableConcept" = None,
        severity: "CodeableConcept" = None,
        outcome: "CodeableConcept" = None,
        recorder: "Reference" = None,
        contributor: list["Reference"] = None,
        suspectEntity: list["SuspectEntity"] = None,
        subjectMedicalHistory: list["Reference"] = None,
        referenceDocument: list["Reference"] = None,
        study: list["Reference"] = None,
    ):

        self.resourceType = "AdverseEvent"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier
        self.actuality = actuality
        self.category = category or []
        self.event = event
        self.subject = subject
        self.encounter = encounter
        self.date = date
        self.detected = detected
        self.recordedDate = recordedDate
        self.resultingCondition = resultingCondition or []
        self.location = location
        self.seriousness = seriousness
        self.severity = severity
        self.outcome = outcome
        self.recorder = recorder
        self.contributor = contributor or []
        self.suspectEntity = suspectEntity or []
        self.subjectMedicalHistory = subjectMedicalHistory or []
        self.referenceDocument = referenceDocument or []
        self.study = study or []

    @classmethod
    def from_dict(cls, data: dict) -> "AdverseEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AdverseEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Expression. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4.Extension import *


class Expression(FhirBaseModel):
    """Base StructureDefinition for Expression Type: A expression that is evaluated in a specified context and returns a value. The context of use of the expression must specify the context in which the expression is evaluated, and how the result of the expression is used.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str description: Natural language description of the condition
    :param str name: Short name assigned to expression for reuse
    :param str language: text/cql | text/fhirpath | application/x-fhir-query | etc.
    :param str expression: Expression in specified language
    :param str reference: Where the expression is found
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        description: "str" = None,
        name: "str" = None,
        language: "str" = None,
        expression: "str" = None,
        reference: "str" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.description = description
        self.name = name
        self.language = language
        self.expression = expression
        self.reference = reference

    @classmethod
    def from_dict(cls, data: dict) -> "Expression":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Expression":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



# SETTINGS
DEFAULT_OUTPUT_DIR = "."
TEMPLATE_DIR = "."
STRUC_DEF_TEMPLATE_NAME: str = "structure_definition_model.j2"
MODEL_TEMPLATE_NAME: str = "model_init.j2"

# FHIR
FHIR_VERSION_PACKAGE_URLS = {
    "R4": "https://hl7.org/fhir/R4/hl7.fhir.r4.core.tgz",
    "R4B": "https://hl7.org/fhir/R4B/hl7.fhir.r4b.core.tgz",
    "R5": "https://hl7.org/fhir/hl7.fhir.r5.core.tgz",
}
DOMAIN_RESOURCE_STRUC_DEF_URL = "http://hl7.org/fhir/StructureDefinition/DomainResource"

# RESOURCE TYPES
ACCOUNT = "Account"
ACTIVITYDEFINITION = "ActivityDefinition"
ADVERSEEVENT = "AdverseEvent"
ALLERGYINTOLERANCE = "AllergyIntolerance"
APPOINTMENT = "Appointment"
APPOINTMENTRESPONSE = "AppointmentResponse"
AUDITEVENT = "AuditEvent"
BASIC = "Basic"
BIOLOGICALLYDERIVEDPRODUCT = "BiologicallyDerivedProduct"
BODYSTRUCTURE = "BodyStructure"
CAPABILITYSTATEMENT = "CapabilityStatement"
CAREPLAN = "CarePlan"
CARETEAM = "CareTeam"
CATALOGENTRY = "CatalogEntry"
CHARGEITEM = "ChargeItem"
CHARGEITEMDEFINITION = "ChargeItemDefinition"
CLAIM = "Claim"
CLAIMRESPONSE = "ClaimResponse"
CLINICALIMPRESSION = "ClinicalImpression"
CODESYSTEM = "CodeSystem"
COMMUNICATION = "Communication"
COMMUNICATIONREQUEST = "CommunicationRequest"
COMPARTMENTDEFINITION = "CompartmentDefinition"
COMPOSITION = "Composition"
CONCEPTMAP = "ConceptMap"
CONDITION = "Condition"
CONSENT = "Consent"
CONTRACT = "Contract"
COVERAGE = "Coverage"
COVERAGEELIGIBILITYREQUEST = "CoverageEligibilityRequest"
COVERAGEELIGIBILITYRESPONSE = "CoverageEligibilityResponse"
DETECTEDISSUE = "DetectedIssue"
DEVICE = "Device"
DEVICEDEFINITION = "DeviceDefinition"
DEVICEMETRIC = "DeviceMetric"
DEVICEREQUEST = "DeviceRequest"
DEVICEUSESTATEMENT = "DeviceUseStatement"
DIAGNOSTICREPORT = "DiagnosticReport"
DOCUMENTMANIFEST = "DocumentManifest"
DOCUMENTREFERENCE = "DocumentReference"
EFFECTEVIDENCESYNTHESIS = "EffectEvidenceSynthesis"
ENCOUNTER = "Encounter"
ENDPOINT = "Endpoint"
ENROLLMENTREQUEST = "EnrollmentRequest"
ENROLLMENTRESPONSE = "EnrollmentResponse"
EPISODEOFCARE = "EpisodeOfCare"
EVENTDEFINITION = "EventDefinition"
EVIDENCE = "Evidence"
EVIDENCEVARIABLE = "EvidenceVariable"
EXAMPLESCENARIO = "ExampleScenario"
EXPLANATIONOFBENEFIT = "ExplanationOfBenefit"
FAMILYMEMBERHISTORY = "FamilyMemberHistory"
FLAG = "Flag"
GOAL = "Goal"
GRAPHDEFINITION = "GraphDefinition"
GROUP = "Group"
GUIDANCERESPONSE = "GuidanceResponse"
HEALTHCARESERVICE = "HealthcareService"
IMAGINGSTUDY = "ImagingStudy"
IMMUNIZATION = "Immunization"
IMMUNIZATIONEVALUATION = "ImmunizationEvaluation"
IMMUNIZATIONRECOMMENDATION = "ImmunizationRecommendation"
IMPLEMENTATIONGUIDE = "ImplementationGuide"
INSURANCEPLAN = "InsurancePlan"
INVOICE = "Invoice"
LIBRARY = "Library"
LINKAGE = "Linkage"
LIST = "List"
LOCATION = "Location"
MEASURE = "Measure"
MEASUREREPORT = "MeasureReport"
MEDIA = "Media"
MEDICATION = "Medication"
MEDICATIONADMINISTRATION = "MedicationAdministration"
MEDICATIONDISPENSE = "MedicationDispense"
MEDICATIONKNOWLEDGE = "MedicationKnowledge"
MEDICATIONREQUEST = "MedicationRequest"
MEDICATIONSTATEMENT = "MedicationStatement"
MEDICINALPRODUCT = "MedicinalProduct"
MEDICINALPRODUCTAUTHORIZATION = "MedicinalProductAuthorization"
MEDICINALPRODUCTCONTRAINDICATION = "MedicinalProductContraindication"
MEDICINALPRODUCTINDICATION = "MedicinalProductIndication"
MEDICINALPRODUCTINGREDIENT = "MedicinalProductIngredient"
MEDICINALPRODUCTINTERACTION = "MedicinalProductInteraction"
MEDICINALPRODUCTMANUFACTURED = "MedicinalProductManufactured"
MEDICINALPRODUCTPACKAGED = "MedicinalProductPackaged"
MEDICINALPRODUCTPHARMACEUTICAL = "MedicinalProductPharmaceutical"
MEDICINALPRODUCTUNDESIRABLEEFFECT = "MedicinalProductUndesirableEffect"
MESSAGEDEFINITION = "MessageDefinition"
MESSAGEHEADER = "MessageHeader"
MOLECULARSEQUENCE = "MolecularSequence"
NAMINGSYSTEM = "NamingSystem"
NUTRITIONORDER = "NutritionOrder"
OBSERVATION = "Observation"
OBSERVATIONDEFINITION = "ObservationDefinition"
OPERATIONDEFINITION = "OperationDefinition"
OPERATIONOUTCOME = "OperationOutcome"
ORGANIZATION = "Organization"
ORGANIZATIONAFFILIATION = "OrganizationAffiliation"
PATIENT = "Patient"
PAYMENTNOTICE = "PaymentNotice"
PAYMENTRECONCILIATION = "PaymentReconciliation"
PERSON = "Person"
PLANDEFINITION = "PlanDefinition"
PRACTITIONER = "Practitioner"
PRACTITIONERROLE = "PractitionerRole"
PROCEDURE = "Procedure"
PROVENANCE = "Provenance"
QUESTIONNAIRE = "Questionnaire"
QUESTIONNAIRERESPONSE = "QuestionnaireResponse"
RELATEDPERSON = "RelatedPerson"
REQUESTGROUP = "RequestGroup"
RESEARCHDEFINITION = "ResearchDefinition"
RESEARCHELEMENTDEFINITION = "ResearchElementDefinition"
RESEARCHSTUDY = "ResearchStudy"
RESEARCHSUBJECT = "ResearchSubject"
RESOURCE = "Resource"
RISKASSESSMENT = "RiskAssessment"
RISKEVIDENCESYNTHESIS = "RiskEvidenceSynthesis"
SCHEDULE = "Schedule"
SEARCHPARAMETER = "SearchParameter"
SERVICEREQUEST = "ServiceRequest"
SLOT = "Slot"
SPECIMEN = "Specimen"
SPECIMENDEFINITION = "SpecimenDefinition"
STRUCTUREDEFINITION = "StructureDefinition"
STRUCTUREMAP = "StructureMap"
SUBSCRIPTION = "Subscription"
SUBSTANCE = "Substance"
SUBSTANCENUCLEICACID = "SubstanceNucleicAcid"
SUBSTANCEPOLYMER = "SubstancePolymer"
SUBSTANCEPROTEIN = "SubstanceProtein"
SUBSTANCEREFERENCEINFORMATION = "SubstanceReferenceInformation"
SUBSTANCESOURCEMATERIAL = "SubstanceSourceMaterial"
SUBSTANCESPECIFICATION = "SubstanceSpecification"
SUPPLYDELIVERY = "SupplyDelivery"
SUPPLYREQUEST = "SupplyRequest"
TASK = "Task"
TERMINOLOGYCAPABILITIES = "TerminologyCapabilities"
TESTREPORT = "TestReport"
TESTSCRIPT = "TestScript"
VALUESET = "ValueSet"
VERIFICATIONRESULT = "VerificationResult"
VISIONPRESCRIPTION = "VisionPrescription"

# PYTHON
PYTHON_KEYWORDS = [
    "False",
    "None",
    "True",
    "and",
    "as",
    "assert",
    "async",
    "await",
    "break",
    "class",
    "continue",
    "def",
    "del",
    "elif",
    "else",
    "except",
    "finally",
    "for",
    "from",
    "global",
    "if",
    "import",
    "in",
    "is",
    "lambda",
    "nonlocal",
    "not",
    "or",
    "pass",
    "raise",
    "return",
    "try",
    "while",
    "with",
    "yield",
]
FHIR_PRIMITIVES_TO_PYTHON_MAP = {
    "base64Binary": str,
    "boolean": bool,
    "canonical": str,
    "code": str,
    "date": str,
    "dateTime": str,
    "decimal": float,
    "id": str,
    "instant": str,
    "integer": int,
    "integer64": int,
    "markdown": str,
    "oid": str,
    "positiveInt": int,
    "string": str,
    "time": str,
    "unsignedInt": int,
    "uri": str,
    "url": str,
    "uuid": str,
    "xhtml": str,
}
FHIR_PRIMITIVE_EXPANSION_MAP = {
    "http://hl7.org/fhirpath/System.String": "string",
    "http://hl7.org/fhirpath/System.Boolean": "boolean",
    "http://hl7.org/fhirpath/System.Integer": "integer",
    "http://hl7.org/fhirpath/System.Decimal": "decimal",
    "http://hl7.org/fhirpath/System.DateTime": "dateTime",
    "http://hl7.org/fhirpath/System.Date": "date",
    "http://hl7.org/fhirpath/System.Time": "time",
}



"""
Generated class for Composition. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.RelatedArtifact import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.UsageContext import *


class Attester(FhirBaseModel):
    """A participant who has attested to the accuracy of the composition/document.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept mode: personal | professional | legal | official
    :param str time: When the composition was attested
    :param Reference party: Who attested the composition
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "mode": {"class_name": "CodeableConcept", "is_contained": False},
        "party": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        mode: "CodeableConcept" = None,
        time: "str" = None,
        party: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.mode = mode
        self.time = time
        self.party = party

    @classmethod
    def from_dict(cls, data: dict) -> "Composition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Composition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Event(FhirBaseModel):
    """The clinical service, such as a colonoscopy or an appendectomy, being documented.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Period period: The period covered by the documentation
    :param CodeableReference detail: The event(s) being documented, as code(s), reference(s), or both
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "detail": {"class_name": "CodeableReference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        period: "Period" = None,
        detail: list["CodeableReference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.period = period
        self.detail = detail or []

    @classmethod
    def from_dict(cls, data: dict) -> "Composition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Composition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Section(FhirBaseModel):
    """The root of the sections that make up the composition.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str title: Label for section (e.g. for ToC)
    :param CodeableConcept code: Classification of section (recommended)
    :param Reference author: Who and/or what authored the section
    :param Reference focus: Who/what the section is about, when it is not about the subject of composition
    :param Narrative text: Text summary of the section, for human interpretation
    :param CodeableConcept orderedBy: Order of section entries
    :param Reference entry: A reference to data that supports this section
    :param CodeableConcept emptyReason: Why the section is empty
    :param Section section: Nested Section
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "author": {"class_name": "Reference", "is_contained": False},
        "focus": {"class_name": "Reference", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "orderedBy": {"class_name": "CodeableConcept", "is_contained": False},
        "entry": {"class_name": "Reference", "is_contained": False},
        "emptyReason": {"class_name": "CodeableConcept", "is_contained": False},
        "section": {"class_name": "Section", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        title: "str" = None,
        code: "CodeableConcept" = None,
        author: list["Reference"] = None,
        focus: "Reference" = None,
        text: "Narrative" = None,
        orderedBy: "CodeableConcept" = None,
        entry: list["Reference"] = None,
        emptyReason: "CodeableConcept" = None,
        section: list["Section"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.title = title
        self.code = code
        self.author = author or []
        self.focus = focus
        self.text = text
        self.orderedBy = orderedBy
        self.entry = entry or []
        self.emptyReason = emptyReason
        self.section = section or []

    @classmethod
    def from_dict(cls, data: dict) -> "Composition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Composition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Composition(DomainResource):
    """A set of healthcare-related information that is assembled together into a single logical package that provides a single coherent statement of meaning, establishes its own context and that has clinical attestation with regard to who is making the statement. A Composition defines the structure and narrative content necessary for a document. However, a Composition alone does not constitute a document. Rather, the Composition must be the first entry in a Bundle where Bundle.type=document, and any other resources referenced from Composition must be included as subsequent entries in the Bundle (for example Patient, Practitioner, Encounter, etc.).
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this Composition, represented as a URI (globally unique)
    :param Identifier identifier: Version-independent identifier for the Composition
    :param str version: An explicitly assigned identifer of a variation of the content in the Composition
    :param str status: registered | partial | preliminary | final | amended | corrected | appended | cancelled | entered-in-error | deprecated | unknown
    :param CodeableConcept type: Kind of composition (LOINC if possible)
    :param CodeableConcept category: Categorization of Composition
    :param Reference subject: Who and/or what the composition is about
    :param Reference encounter: Context of the Composition
    :param str date: Composition editing time
    :param UsageContext useContext: The context that the content is intended to support
    :param Reference author: Who and/or what authored the composition
    :param str name: Name for this Composition (computer friendly)
    :param str title: Human Readable name/title
    :param Annotation note: For any additional notes
    :param Attester attester: Attests to accuracy of composition
    :param Reference custodian: Organization which maintains the composition
    :param RelatedArtifact relatesTo: Relationships to other compositions/documents
    :param Event event: The clinical service(s) being documented
    :param Section section: Composition is broken into sections
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "author": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "attester": {"class_name": "Attester", "is_contained": True},
        "custodian": {"class_name": "Reference", "is_contained": False},
        "relatesTo": {"class_name": "RelatedArtifact", "is_contained": False},
        "event": {"class_name": "Event", "is_contained": True},
        "section": {"class_name": "Section", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        status: "str" = None,
        type: "CodeableConcept" = None,
        category: list["CodeableConcept"] = None,
        subject: list["Reference"] = None,
        encounter: "Reference" = None,
        date: "str" = None,
        useContext: list["UsageContext"] = None,
        author: list["Reference"] = None,
        name: "str" = None,
        title: "str" = None,
        note: list["Annotation"] = None,
        attester: list["Attester"] = None,
        custodian: "Reference" = None,
        relatesTo: list["RelatedArtifact"] = None,
        event: list["Event"] = None,
        section: list["Section"] = None,
    ):

        self.resourceType = "Composition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.status = status
        self.type = type
        self.category = category or []
        self.subject = subject or []
        self.encounter = encounter
        self.date = date
        self.useContext = useContext or []
        self.author = author or []
        self.name = name
        self.title = title
        self.note = note or []
        self.attester = attester or []
        self.custodian = custodian
        self.relatesTo = relatesTo or []
        self.event = event or []
        self.section = section or []

    @classmethod
    def from_dict(cls, data: dict) -> "Composition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Composition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Device. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.Annotation import *
from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.ContactPoint import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Quantity import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class UdiCarrier(FhirBaseModel):
    """Unique device identifier (UDI) assigned to device label or package.  Note that the Device may include multiple udiCarriers as it either may include just the udiCarrier for the jurisdiction it is sold, or for multiple jurisdictions it could have been sold.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str deviceIdentifier: Mandatory fixed portion of UDI
    :param str issuer: UDI Issuing Organization
    :param str jurisdiction: Regional UDI authority
    :param str carrierAIDC: UDI Machine Readable Barcode String
    :param str carrierHRF: UDI Human Readable Barcode String
    :param str entryType: barcode | rfid | manual +
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        deviceIdentifier: "str" = None,
        issuer: "str" = None,
        jurisdiction: "str" = None,
        carrierAIDC: "str" = None,
        carrierHRF: "str" = None,
        entryType: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.deviceIdentifier = deviceIdentifier
        self.issuer = issuer
        self.jurisdiction = jurisdiction
        self.carrierAIDC = carrierAIDC
        self.carrierHRF = carrierHRF
        self.entryType = entryType

    @classmethod
    def from_dict(cls, data: dict) -> "Device":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Device":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DeviceName(FhirBaseModel):
    """This represents the manufacturer's name of the device as provided by the device, from a UDI label, or by a person describing the Device.  This typically would be used when a person provides the name(s) or when the device represents one of the names available from DeviceDefinition.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: The name of the device
    :param str type: udi-label-name | user-friendly-name | patient-reported-name | manufacturer-name | model-name | other
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        type: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.type = type

    @classmethod
    def from_dict(cls, data: dict) -> "Device":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Device":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Specialization(FhirBaseModel):
    """The capabilities supported on a  device, the standards to which the device conforms for a particular purpose, and used for the communication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept systemType: The standard that is used to operate and communicate
    :param str version: The version of the standard that is used to operate and communicate
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "systemType": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        systemType: "CodeableConcept" = None,
        version: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.systemType = systemType
        self.version = version

    @classmethod
    def from_dict(cls, data: dict) -> "Device":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Device":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Version(FhirBaseModel):
    """The actual design of the device or software version running on the device.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The type of the device version
    :param Identifier component: A single component of the device version
    :param str value: The version text
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "component": {"class_name": "Identifier", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        component: "Identifier" = None,
        value: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.component = component
        self.value = value

    @classmethod
    def from_dict(cls, data: dict) -> "Device":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Device":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Property(FhirBaseModel):
    """The actual configuration settings of a device as it actually operates, e.g., regulation status, time properties.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Code that specifies the property DeviceDefinitionPropetyCode (Extensible)
    :param Quantity valueQuantity: Property value as a quantity
    :param CodeableConcept valueCode: Property value as a code, e.g., NTP4 (synced to NTP)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueCode": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        valueQuantity: list["Quantity"] = None,
        valueCode: list["CodeableConcept"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueQuantity = valueQuantity or []
        self.valueCode = valueCode or []

    @classmethod
    def from_dict(cls, data: dict) -> "Device":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Device":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Device(DomainResource):
    """A type of a manufactured item that is used in the provision of healthcare without being substantially changed through that activity. The device may be a medical or non-medical device.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Instance identifier
    :param Reference definition: The reference to the definition for the device
    :param UdiCarrier udiCarrier: Unique Device Identifier (UDI) Barcode string
    :param str status: active | inactive | entered-in-error | unknown
    :param CodeableConcept statusReason: online | paused | standby | offline | not-ready | transduc-discon | hw-discon | off
    :param str distinctIdentifier: The distinct identification string
    :param str manufacturer: Name of device manufacturer
    :param str manufactureDate: Date when the device was made
    :param str expirationDate: Date and time of expiry of this device (if applicable)
    :param str lotNumber: Lot number of manufacture
    :param str serialNumber: Serial number assigned by the manufacturer
    :param DeviceName deviceName: The name of the device as given by the manufacturer
    :param str modelNumber: The model number for the device
    :param str partNumber: The part number of the device
    :param CodeableConcept type: The kind or type of device
    :param Specialization specialization: The capabilities supported on a  device, the standards to which the device conforms for a particular purpose, and used for the communication
    :param Version version: The actual design of the device or software version running on the device
    :param Property property: The actual configuration settings of a device as it actually operates, e.g., regulation status, time properties
    :param Reference patient: Patient to whom Device is affixed
    :param Reference owner: Organization responsible for device
    :param ContactPoint contact: Details for human/organization for support
    :param Reference location: Where the device is found
    :param str url: Network address to contact device
    :param Annotation note: Device notes and comments
    :param CodeableConcept safety: Safety Characteristics of Device
    :param Reference parent: The parent device
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "definition": {"class_name": "Reference", "is_contained": False},
        "udiCarrier": {"class_name": "UdiCarrier", "is_contained": True},
        "statusReason": {"class_name": "CodeableConcept", "is_contained": False},
        "deviceName": {"class_name": "DeviceName", "is_contained": True},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "specialization": {"class_name": "Specialization", "is_contained": True},
        "version": {"class_name": "Version", "is_contained": True},
        "property": {"class_name": "Property", "is_contained": True},
        "patient": {"class_name": "Reference", "is_contained": False},
        "owner": {"class_name": "Reference", "is_contained": False},
        "contact": {"class_name": "ContactPoint", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "safety": {"class_name": "CodeableConcept", "is_contained": False},
        "parent": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        definition: "Reference" = None,
        udiCarrier: list["UdiCarrier"] = None,
        status: "str" = None,
        statusReason: list["CodeableConcept"] = None,
        distinctIdentifier: "str" = None,
        manufacturer: "str" = None,
        manufactureDate: "str" = None,
        expirationDate: "str" = None,
        lotNumber: "str" = None,
        serialNumber: "str" = None,
        deviceName: list["DeviceName"] = None,
        modelNumber: "str" = None,
        partNumber: "str" = None,
        type: "CodeableConcept" = None,
        specialization: list["Specialization"] = None,
        version: list["Version"] = None,
        property: list["Property"] = None,
        patient: "Reference" = None,
        owner: "Reference" = None,
        contact: list["ContactPoint"] = None,
        location: "Reference" = None,
        url: "str" = None,
        note: list["Annotation"] = None,
        safety: list["CodeableConcept"] = None,
        parent: "Reference" = None,
    ):

        self.resourceType = "Device"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.definition = definition
        self.udiCarrier = udiCarrier or []
        self.status = status
        self.statusReason = statusReason or []
        self.distinctIdentifier = distinctIdentifier
        self.manufacturer = manufacturer
        self.manufactureDate = manufactureDate
        self.expirationDate = expirationDate
        self.lotNumber = lotNumber
        self.serialNumber = serialNumber
        self.deviceName = deviceName or []
        self.modelNumber = modelNumber
        self.partNumber = partNumber
        self.type = type
        self.specialization = specialization or []
        self.version = version or []
        self.property = property or []
        self.patient = patient
        self.owner = owner
        self.contact = contact or []
        self.location = location
        self.url = url
        self.note = note or []
        self.safety = safety or []
        self.parent = parent

    @classmethod
    def from_dict(cls, data: dict) -> "Device":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Device":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for SpecimenDefinition. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Duration import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Range import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Additive(FhirBaseModel):
    """Substance introduced in the kind of container to preserve, maintain or enhance the specimen. Examples: Formalin, Citrate, EDTA.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept additiveCodeableConcept: Additive associated with container
    :param Reference additiveReference: Additive associated with container
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "additiveCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "additiveReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        additiveCodeableConcept: "CodeableConcept" = None,
        additiveReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.additiveCodeableConcept = additiveCodeableConcept
        self.additiveReference = additiveReference

    @classmethod
    def from_dict(cls, data: dict) -> "SpecimenDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SpecimenDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Container(FhirBaseModel):
    """The specimen's container.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept material: Container material
    :param CodeableConcept type: Kind of container associated with the kind of specimen
    :param CodeableConcept cap: Color of container cap
    :param str description: Container description
    :param Quantity capacity: Container capacity
    :param Quantity minimumVolumeQuantity: Minimum volume
    :param str minimumVolumeString: Minimum volume
    :param Additive additive: Additive associated with container
    :param str preparation: Specimen container preparation
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "material": {"class_name": "CodeableConcept", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "cap": {"class_name": "CodeableConcept", "is_contained": False},
        "capacity": {"class_name": "Quantity", "is_contained": False},
        "minimumVolumeQuantity": {"class_name": "Quantity", "is_contained": False},
        "additive": {"class_name": "Additive", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        material: "CodeableConcept" = None,
        type: "CodeableConcept" = None,
        cap: "CodeableConcept" = None,
        description: "str" = None,
        capacity: "Quantity" = None,
        minimumVolumeQuantity: "Quantity" = None,
        minimumVolumeString: "str" = None,
        additive: list["Additive"] = None,
        preparation: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.material = material
        self.type = type
        self.cap = cap
        self.description = description
        self.capacity = capacity
        self.minimumVolumeQuantity = minimumVolumeQuantity
        self.minimumVolumeString = minimumVolumeString
        self.additive = additive or []
        self.preparation = preparation

    @classmethod
    def from_dict(cls, data: dict) -> "SpecimenDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SpecimenDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Handling(FhirBaseModel):
    """Set of instructions for preservation/transport of the specimen at a defined temperature interval, prior the testing process.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept temperatureQualifier: Temperature qualifier
    :param Range temperatureRange: Temperature range
    :param Duration maxDuration: Maximum preservation time
    :param str instruction: Preservation instruction
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "temperatureQualifier": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "temperatureRange": {"class_name": "Range", "is_contained": False},
        "maxDuration": {"class_name": "Duration", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        temperatureQualifier: "CodeableConcept" = None,
        temperatureRange: "Range" = None,
        maxDuration: "Duration" = None,
        instruction: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.temperatureQualifier = temperatureQualifier
        self.temperatureRange = temperatureRange
        self.maxDuration = maxDuration
        self.instruction = instruction

    @classmethod
    def from_dict(cls, data: dict) -> "SpecimenDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SpecimenDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class TypeTested(FhirBaseModel):
    """Specimen conditioned in a container as expected by the testing laboratory.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param bool isDerived: Primary or secondary specimen
    :param CodeableConcept type: Type of intended specimen
    :param str preference: preferred | alternate
    :param Container container: The specimen's container
    :param str requirement: Specimen requirements
    :param Duration retentionTime: Specimen retention time
    :param CodeableConcept rejectionCriterion: Rejection criterion
    :param Handling handling: Specimen handling before testing
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "container": {"class_name": "Container", "is_contained": True},
        "retentionTime": {"class_name": "Duration", "is_contained": False},
        "rejectionCriterion": {"class_name": "CodeableConcept", "is_contained": False},
        "handling": {"class_name": "Handling", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        isDerived: "bool" = None,
        type: "CodeableConcept" = None,
        preference: "str" = None,
        container: "Container" = None,
        requirement: "str" = None,
        retentionTime: "Duration" = None,
        rejectionCriterion: list["CodeableConcept"] = None,
        handling: list["Handling"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.isDerived = isDerived
        self.type = type
        self.preference = preference
        self.container = container
        self.requirement = requirement
        self.retentionTime = retentionTime
        self.rejectionCriterion = rejectionCriterion or []
        self.handling = handling or []

    @classmethod
    def from_dict(cls, data: dict) -> "SpecimenDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SpecimenDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SpecimenDefinition(DomainResource):
    """A kind of specimen with associated set of requirements.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier of a kind of specimen
    :param CodeableConcept typeCollected: Kind of material to collect
    :param CodeableConcept patientPreparation: Patient preparation for collection
    :param str timeAspect: Time aspect for collection
    :param CodeableConcept collection: Specimen collection procedure
    :param TypeTested typeTested: Specimen in container intended for testing by lab
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "typeCollected": {"class_name": "CodeableConcept", "is_contained": False},
        "patientPreparation": {"class_name": "CodeableConcept", "is_contained": False},
        "collection": {"class_name": "CodeableConcept", "is_contained": False},
        "typeTested": {"class_name": "TypeTested", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: "Identifier" = None,
        typeCollected: "CodeableConcept" = None,
        patientPreparation: list["CodeableConcept"] = None,
        timeAspect: "str" = None,
        collection: list["CodeableConcept"] = None,
        typeTested: list["TypeTested"] = None,
    ):

        self.resourceType = "SpecimenDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier
        self.typeCollected = typeCollected
        self.patientPreparation = patientPreparation or []
        self.timeAspect = timeAspect
        self.collection = collection or []
        self.typeTested = typeTested or []

    @classmethod
    def from_dict(cls, data: dict) -> "SpecimenDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SpecimenDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for PackagedProductDefinition. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Attachment import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.MarketingStatus import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.ProductShelfLife import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class LegalStatusOfSupply(FhirBaseModel):
    """The legal status of supply of the packaged item as classified by the regulator.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: The actual status of supply. In what situation this package type may be supplied for use
    :param CodeableConcept jurisdiction: The place where the legal status of supply applies
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        jurisdiction: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.jurisdiction = jurisdiction

    @classmethod
    def from_dict(cls, data: dict) -> "PackagedProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PackagedProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Property(FhirBaseModel):
    """General characteristics of this item.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: A code expressing the type of characteristic
    :param CodeableConcept valueCodeableConcept: A value for the characteristic
    :param Quantity valueQuantity: A value for the characteristic
    :param str valueDate: A value for the characteristic
    :param bool valueBoolean: A value for the characteristic
    :param Attachment valueAttachment: A value for the characteristic
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueAttachment": {"class_name": "Attachment", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueQuantity: "Quantity" = None,
        valueDate: "str" = None,
        valueBoolean: "bool" = None,
        valueAttachment: "Attachment" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueCodeableConcept = valueCodeableConcept
        self.valueQuantity = valueQuantity
        self.valueDate = valueDate
        self.valueBoolean = valueBoolean
        self.valueAttachment = valueAttachment

    @classmethod
    def from_dict(cls, data: dict) -> "PackagedProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PackagedProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ContainedItem(FhirBaseModel):
    """The item(s) within the packaging.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference item: The actual item(s) of medication, as manufactured, or a device, or other medically related item (food, biologicals, raw materials, medical fluids, gases etc.), as contained in the package
    :param Quantity amount: The number of this type of item within this packaging or for continuous items such as liquids it is the quantity (for example 25ml). See also PackagedProductDefinition.containedItemQuantity (especially the long definition)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "item": {"class_name": "CodeableReference", "is_contained": False},
        "amount": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        item: "CodeableReference" = None,
        amount: "Quantity" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.item = item
        self.amount = amount

    @classmethod
    def from_dict(cls, data: dict) -> "PackagedProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PackagedProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Packaging(FhirBaseModel):
    """A packaging item, as a container for medically related items, possibly with other packaging items within, or a packaging component, such as bottle cap (which is not a device or a medication manufactured item).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier identifier: An identifier that is specific to this particular part of the packaging. Including possibly a Data Carrier Identifier
    :param CodeableConcept type: The physical type of the container of the items
    :param bool componentPart: Is this a part of the packaging (e.g. a cap or bottle stopper), rather than the packaging itself (e.g. a bottle or vial)
    :param int quantity: The quantity of this level of packaging in the package that contains it (with the outermost level being 1)
    :param CodeableConcept material: Material type of the package item
    :param CodeableConcept alternateMaterial: A possible alternate material for this part of the packaging, that is allowed to be used instead of the usual material
    :param ProductShelfLife shelfLifeStorage: Shelf Life and storage information
    :param Reference manufacturer: Manufacturer of this packaging item (multiple means these are all potential manufacturers)
    :param Property property: General characteristics of this item
    :param ContainedItem containedItem: The item(s) within the packaging
    :param Packaging packaging: Allows containers (and parts of containers) within containers, still as a part of single packaged product
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "material": {"class_name": "CodeableConcept", "is_contained": False},
        "alternateMaterial": {"class_name": "CodeableConcept", "is_contained": False},
        "shelfLifeStorage": {"class_name": "ProductShelfLife", "is_contained": False},
        "manufacturer": {"class_name": "Reference", "is_contained": False},
        "property": {"class_name": "Property", "is_contained": True},
        "containedItem": {"class_name": "ContainedItem", "is_contained": True},
        "packaging": {"class_name": "Packaging", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        type: "CodeableConcept" = None,
        componentPart: "bool" = None,
        quantity: "int" = None,
        material: list["CodeableConcept"] = None,
        alternateMaterial: list["CodeableConcept"] = None,
        shelfLifeStorage: list["ProductShelfLife"] = None,
        manufacturer: list["Reference"] = None,
        property: list["Property"] = None,
        containedItem: list["ContainedItem"] = None,
        packaging: list["Packaging"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.type = type
        self.componentPart = componentPart
        self.quantity = quantity
        self.material = material or []
        self.alternateMaterial = alternateMaterial or []
        self.shelfLifeStorage = shelfLifeStorage or []
        self.manufacturer = manufacturer or []
        self.property = property or []
        self.containedItem = containedItem or []
        self.packaging = packaging or []

    @classmethod
    def from_dict(cls, data: dict) -> "PackagedProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PackagedProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class PackagedProductDefinition(DomainResource):
    """A medically related item or items, in a container or package.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: A unique identifier for this package as whole - not for the content of the package
    :param str name: A name for this package. Typically as listed in a drug formulary, catalogue, inventory etc
    :param CodeableConcept type: A high level category e.g. medicinal product, raw material, shipping container etc
    :param Reference packageFor: The product that this is a pack for
    :param CodeableConcept status: The status within the lifecycle of this item. High level - not intended to duplicate details elsewhere e.g. legal status, or authorization/marketing status
    :param str statusDate: The date at which the given status became applicable
    :param Quantity containedItemQuantity: A total of the complete count of contained items of a particular type/form, independent of sub-packaging or organization. This can be considered as the pack size. See also packaging.containedItem.amount (especially the long definition)
    :param str description: Textual description. Note that this is not the name of the package or product
    :param LegalStatusOfSupply legalStatusOfSupply: The legal status of supply of the packaged item as classified by the regulator
    :param MarketingStatus marketingStatus: Allows specifying that an item is on the market for sale, or that it is not available, and the dates and locations associated
    :param bool copackagedIndicator: Identifies if the drug product is supplied with another item such as a diluent or adjuvant
    :param Reference manufacturer: Manufacturer of this package type (multiple means these are all possible manufacturers)
    :param Reference attachedDocument: Additional information or supporting documentation about the packaged product
    :param Packaging packaging: A packaging item, as a container for medically related items, possibly with other packaging items within, or a packaging component, such as bottle cap
    :param Characteristic characteristic: Allows the key features to be recorded, such as "hospital pack", "nurse prescribable"
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "packageFor": {"class_name": "Reference", "is_contained": False},
        "status": {"class_name": "CodeableConcept", "is_contained": False},
        "containedItemQuantity": {"class_name": "Quantity", "is_contained": False},
        "legalStatusOfSupply": {
            "class_name": "LegalStatusOfSupply",
            "is_contained": True,
        },
        "marketingStatus": {"class_name": "MarketingStatus", "is_contained": False},
        "manufacturer": {"class_name": "Reference", "is_contained": False},
        "attachedDocument": {"class_name": "Reference", "is_contained": False},
        "packaging": {"class_name": "Packaging", "is_contained": True},
        "characteristic": {"class_name": "Characteristic", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        name: "str" = None,
        type: "CodeableConcept" = None,
        packageFor: list["Reference"] = None,
        status: "CodeableConcept" = None,
        statusDate: "str" = None,
        containedItemQuantity: list["Quantity"] = None,
        description: "str" = None,
        legalStatusOfSupply: list["LegalStatusOfSupply"] = None,
        marketingStatus: list["MarketingStatus"] = None,
        copackagedIndicator: "bool" = None,
        manufacturer: list["Reference"] = None,
        attachedDocument: list["Reference"] = None,
        packaging: "Packaging" = None,
        characteristic: list["Characteristic"] = None,
    ):

        self.resourceType = "PackagedProductDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.name = name
        self.type = type
        self.packageFor = packageFor or []
        self.status = status
        self.statusDate = statusDate
        self.containedItemQuantity = containedItemQuantity or []
        self.description = description
        self.legalStatusOfSupply = legalStatusOfSupply or []
        self.marketingStatus = marketingStatus or []
        self.copackagedIndicator = copackagedIndicator
        self.manufacturer = manufacturer or []
        self.attachedDocument = attachedDocument or []
        self.packaging = packaging
        self.characteristic = characteristic or []

    @classmethod
    def from_dict(cls, data: dict) -> "PackagedProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PackagedProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Annotation. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Reference import *


class Annotation(FhirBaseModel):
    """Base StructureDefinition for Annotation Type: A  text note which also  contains information about who made the statement and when.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Reference authorReference: Individual responsible for the annotation
    :param str authorString: Individual responsible for the annotation
    :param str time: When the annotation was made
    :param str text: The annotation  - text content (as markdown)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "authorReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        authorReference: "Reference" = None,
        authorString: "str" = None,
        time: "str" = None,
        text: "str" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.authorReference = authorReference
        self.authorString = authorString
        self.time = time
        self.text = text

    @classmethod
    def from_dict(cls, data: dict) -> "Annotation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Annotation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()
